;=========================================
;======== numpadShortcuts.ahk ============
;=========================================
;addon that empowers the numpad, especially useful for left-handers that use
;pen & tablet! Includes "zBrush-like" zooming for faster 3d navigation and
;also various other shortcuts as described on https://www.slyce.at

;=========================================
;================ Chrome =================
;=========================================
#If WinActive("ahk_exe chrome.exe")
	NumpadSub::F11								;num-: maximize view
	NumpadAdd::Browser_Forward		;num+: forward
	NumpadEnter::Browser_Back			;numENTER: back
	NumpadClear::^F5							;num5: refresh page
	NumpadHome::^t								;num7: new tab
	NumpadUp::^+t									;num8: reopen tab
	NumpadPgUp::^w								;num9: close tab
return

;=========================================
;============== Photoshop ================
;=========================================
#If WinActive("ahk_exe Photoshop.exe")
	;general shortcuts
	NumpadClear::LCtrl	;num5: control
	NumpadRight::LAlt		;num6: alt
	NumpadSub::f				;num-: maximize view
	NumpadAdd::+^z			;num+: redo	shift ctrl z
	NumpadEnter::!^z		;numENTER: undo alt ctrl z
	NumpadDel::rbutton	;num,: send RMB
	NumpadIns::Space		;num0: move around canvas

	;move, select & scale
	NumpadEnd::			;num1: brush or move tool
		If (A_PriorHotKey = A_ThisHotKey and A_TimeSincePriorHotkey < 500)
			Send h
		else
			Send b
		return
	NumpadDown::e		;num2: eraser
	NumpadPgDn::m		;num3: marque
return

;=========================================
;================ Unity ==================
;=========================================
#If WinActive("ahk_exe Unity.exe")
	;general shortcuts
	NumpadRight::f			;num6: focus
	NumpadLeft::LCtrl		;Num4
	NumpadHome::^d			;Num7
	NumpadUp::t					;Num8
	NumpadPgup::+!a			;Num9

	NumpadSub::+Space		;num-: maximize view
	NumpadAdd::^y				;num+: redo
	NumpadEnter::^z			;numENTER: undo

	;zoom & navigation
	NumpadIns::				;num0: Zbrush-like zoom
		send, {alt downtemp}
	keywait, NumpadIns
		send, {lbutton up}{alt up}{alt downtemp}{rbutton down}{lbutton downtemp}
	KeyWait, LButton
		send, {rbutton up}{alt up}{lbutton up}
	return

	;move, select & scale
	NumpadEnd::			;num1: move or select (with double tap)
		If (A_PriorHotKey = A_ThisHotKey and A_TimeSincePriorHotkey < 500)
			Send q
		else
			Send w
		return
	NumpadDown::e		;num2: rotate
	NumpadPgDn::r		;num3: scale


	;Num5 add to selection / ctrl+s
	NumpadClear::
	If (A_PriorHotKey = A_ThisHotKey and A_TimeSincePriorHotkey < 600){
		;save scene
		Send {LControl downtemp}{s}
		Send {LControl Up}
		return
	}Else{
		;left control
		Send {LCtrl Down}
		KeyWait, NumpadClear
			Send {LCtrl Up}
		return
	}
	return

	;toggle wireframe/wireframe on shaded (needs a custom script in unity)
	NumpadDiv::F3		;num/: wireframe
	NumpadMult::F4	;numX: wireframe on shaded
return


;=========================================
;=============== 3ds Max =================
;=========================================
#If WinActive("ahk_exe 3dsmax.exe")
	;general shortcuts
	NumpadSub::Send !q		;num-: isolate selected

	;move, select & scale
	NumpadEnd::			;num1: move or select (with double tap)
		If (A_PriorHotKey = A_ThisHotKey and A_TimeSincePriorHotkey < 500)
			Send q
		else
			Send w
		return
	NumpadDown::e		;num2: rotate
	NumpadPgDn::r		;num3: scale

	MButton::
		send, {Alt downtemp}{MButton Down}
	keywait, MButton
		send, {MButton Up}
	return

	NumpadLeft::LCtrl			;Num4
	NumpadClear::LShift		;Num5
	NumpadRight::f				;Num6
	NumpadHome::g					;Num7
	NumpadUp::t						;Num8
	NumpadPgup::p					;Num9

	NumpadEnter::Send ^z	;Num Enter
	NumpadAdd::Send ^y		;Num +
	NumpadDel::Space			;Num entf

	;toggle wireframe/wireframe on shaded
	NumpadDiv::F3		;num/: wireframe
	NumpadMult::F4	;numX: wireframe on shaded

	PgUp::3					;Page Up
	PgDn::1					;Page Down

	;zoom & navigation
	NumpadIns::				;num0: Zbrush-like zoom
		send, {alt downtemp}
	keywait, NumpadIns
		send, {lbutton up}{alt up}{alt downtemp}{rbutton down}{lbutton downtemp}
	KeyWait, LButton
		send, {rbutton up}{alt up}{lbutton up}
	return
return


;=========================================
;================= Maya ==================
;=========================================
#If WinActive("ahk_exe maya.exe")
	;general shortcuts
	NumpadSub::Send ^1		;num-: isolate selected

	/*
	##Custom Numpad Shortcuts##
	a single key can have multiple functions: click once, click twice, hold
	or even clickOnce+hold or clickTwice+hold

	0 -		Navigation
	1 - 	Move / RMB Menu / Move Options
	2 - 	Rotate / Rotate Options
	3	-		Scale / Scale Options

	4 -		-selection / insert edge loop
	5	-		+selection / save scene
	6 -		Focus

	7 -		c menu / d menu
	8 -		RMB edit menu / t menu
	9 -		RMB convert sel menu / repeat last

	/ -		wireframe
	* -		wireframe on shaded
	- -		isolate selection
	+ -		redo
	Ret -	undo
	Del - switch viewport


	*/
	;move, select & scale
	;NumpadEnd::w			;num1: move or select (with double tap)
	;NumpadDown::e		;num2: rotate
	;NumpadPgDn::r		;num3: scale

	;MOVE (click) & RMB MENU (click and hold)
	;SELECT (2 clicks) & MOVE OPTIONS (2 clicks and hold)
	NumpadEnd::
		If (A_PriorHotKey = A_ThisHotKey and A_TimeSincePriorHotkey < 600){
			;select
			Send q

			;move menu
			now := A_TickCount
			while GetKeyState("NumpadEnd", "P")
			{
				if (A_TickCount-now > 200)
				{
					Send {w Down}{LButton Down}
					KeyWait, NumpadEnd
						Send {LButton Up}{w Up}
					return
				}
			}


		}Else{
			;move
			Send w

			;RMB menu
			now := A_TickCount
			while GetKeyState("NumpadEnd", "P")
			{
				if (A_TickCount-now > 200)
				{
					Send {RButton Down}
					KeyWait, NumpadEnd
						Send {RButton Up}
					return
				}
			}

		}
	return

	;ROTATE & ROTATE OPTIONS
	NumpadDown::
		Send e
		now := A_TickCount
		while GetKeyState("NumpadDown", "P")
			if (A_TickCount-now > 500)
			{
				Send {e Down}{LButton Down}
				KeyWait, NumpadDown
					Send {LButton Up}{e Up}
				return
			}
	return

	;SCALE & SCALE OPTIONS
	NumpadPgDn::
		Send r
		now := A_TickCount
		while GetKeyState("NumpadPgDn", "P")
			if (A_TickCount-now > 500)
			{
				Send {r Down}{LButton Down}
				KeyWait, NumpadPgDn
					Send {LButton Up}{r Up}
				return
			}
	return



	MButton::
		send, {Alt downtemp}{MButton Down}
	keywait, MButton
		send, {MButton Up}
	return


	;Num4 -selection / insert edge loop
	NumpadLeft::
	If (A_PriorHotKey = A_ThisHotKey and A_TimeSincePriorHotkey < 600){
		;insert edge loop
		Send {^}{^}
		return
	}Else{
		;left control
		Send {LControl Down}
		KeyWait, NumpadLeft
			Send {LControl Up}
		return
	}
	return


	;Num5 add to selection / ctrl+s
	NumpadClear::
	If (A_PriorHotKey = A_ThisHotKey and A_TimeSincePriorHotkey < 600){
		;save scene
		Send {LControl downtemp}{s}
		Send {LControl Up}
		return
	}Else{
		;left control
		Send {LShift Down}
		KeyWait, NumpadClear
			Send {LShift Up}
		return
	}
	return

	;Num6 fokus
	NumpadRight::f


	;Num7 (c menu, insert edge loop)
	NumpadHome::
	If (A_PriorHotKey = A_ThisHotKey and A_TimeSincePriorHotkey < 600){
		;d menu
		now := A_TickCount
		while GetKeyState("NumpadHome", "P")
		{
			if (A_TickCount-now > 200)
			{
				Send {c Down}{LButton Down}
				KeyWait, NumpadHome
					Send {LButton Up}{c Up}
				return
			}
		}

	}Else{
		;c menu
		now := A_TickCount
		while GetKeyState("NumpadHome", "P")
		{
			if (A_TickCount-now > 200)
			{
				Send {d Down}{LButton Down}
				KeyWait, NumpadHome
					Send {d Up}{LButton Up}
				return
			}
		}
	}
	return


	;Num8 (RMB edit menu, t menu)
	NumpadUp::
		If (A_PriorHotKey = A_ThisHotKey and A_TimeSincePriorHotkey < 600){
			;t menu
			now := A_TickCount
			while GetKeyState("NumpadUp", "P")
			{
				if (A_TickCount-now > 200)
				{
					Send {t Down}{LButton Down}
					KeyWait, NumpadUp
						Send {LButton Up}{t Up}
					return
				}
			}

		}Else{
			;RMB edit menu
			now := A_TickCount
			while GetKeyState("NumpadUp", "P")
			{
				if (A_TickCount-now > 200)
				{
					Send {LShift downtemp}{RButton Down}
					KeyWait, NumpadUp
						Send {RButton Up}
					return
				}
			}
		}
	return

	;Num9 (RMB convert sel menu, d menu)
	NumpadPgup::
		If (A_PriorHotKey = A_ThisHotKey and A_TimeSincePriorHotkey < 600){
			;repeat last command
			Send {g}
			return

		}Else{
			;RMB edit menu
			now := A_TickCount
			while GetKeyState("NumpadPgup", "P")
			{
				if (A_TickCount-now > 200)
				{
					Send {LControl downtemp}{RButton Down}
					KeyWait, NumpadPgup
						Send {RButton Up}
					return
				}
			}
		}
	return


	NumpadEnter::Send ^z	;Num Enter
	NumpadAdd::Send ^y		;Num +
	NumpadDel::Space			;Num entf

	;toggle wireframe/wireframe on shaded
	NumpadDiv::4		;num/: wireframe
	NumpadMult::5		;numX: shaded

	;PgUp::3					;Page Up
	;PgDn::1					;Page Down

	;zoom & navigation
	NumpadIns::				;num0: Zbrush-like zoom
		send, {alt downtemp}
	keywait, NumpadIns
		send, {lbutton up}{alt up}{alt downtemp}{rbutton down}{lbutton downtemp}
	KeyWait, LButton
		send, {rbutton up}{alt up}{lbutton up}
	return
return
